#!/bin/bash
# Docker镜像加速器配置脚本

echo "🔧 配置Docker镜像加速器..."

# 备份原有配置
if [ -f /etc/docker/daemon.json ]; then
    echo "备份现有配置到 /etc/docker/daemon.json.backup"
    cp /etc/docker/daemon.json /etc/docker/daemon.json.backup
fi

# 创建daemon.json配置文件
cat > /etc/docker/daemon.json << 'EOF'
{
  "registry-mirrors": [
    "https://drzsd1vw.mirror.aliyuncs.com",
    "https://docker.mirrors.ustc.edu.cn",
    "https://registry.docker-cn.com"
  ],
  "log-driver": "json-file",
  "log-opts": {
    "max-size": "100m",
    "max-file": "3"
  },
  "storage-driver": "overlay2",
  "exec-opts": ["native.cgroupdriver=systemd"],
  "live-restore": true,
  "features": {
    "buildkit": true
  }
}
EOF

echo "✅ 配置文件已创建:"
cat /etc/docker/daemon.json

echo ""
echo "🔄 重启Docker服务..."
systemctl daemon-reload
systemctl restart docker

echo ""
echo "⏳ 等待Docker服务启动..."
sleep 5

echo ""
echo "🔍 验证配置..."
docker info | grep -A 10 "Registry Mirrors"
docker version

echo ""
echo "✅ Docker镜像加速器配置完成！"
echo "💡 您可以运行以下命令测试："
echo "   docker pull hello-world"
