#!/bin/bash

# Docker Buildx 测试脚本
# 用于验证Buildx安装和配置

echo "🔍 Docker Buildx 测试脚本"
echo "========================="

# 1. 检查Docker版本
echo "📦 Docker版本:"
docker --version

# 2. 检查Buildx版本
echo "🛠️ Buildx版本:"
docker buildx version

# 3. 列出现有构建器
echo "📋 现有构建器:"
docker buildx ls

# 4. 测试创建简单构建器
echo "🏗️ 测试创建构建器..."
if docker buildx create --name test-builder --use --bootstrap; then
    echo "✅ 构建器创建成功"
    
    # 检查构建器状态
    echo "📊 构建器详情:"
    docker buildx inspect test-builder
    
    # 清理测试构建器
    echo "🧹 清理测试构建器..."
    docker buildx rm test-builder
    echo "✅ 测试完成"
else
    echo "❌ 构建器创建失败"
fi

# 5. 测试简单构建
echo "🐳 测试简单Docker构建..."
mkdir -p /tmp/buildx-test
cat > /tmp/buildx-test/Dockerfile << 'EOF'
FROM alpine:latest
RUN echo "Buildx test successful" > /test.txt
CMD cat /test.txt
EOF

cd /tmp/buildx-test
if docker buildx build --platform linux/amd64 -t buildx-test . --load; then
    echo "✅ Buildx构建测试成功"
    docker run --rm buildx-test
    docker rmi buildx-test
else
    echo "❌ Buildx构建测试失败"
fi

# 清理
rm -rf /tmp/buildx-test

echo "🎉 测试完成！"
